@@ -24,6 +24,41 @@ __PACKAGE__->mk_group_accessors( 'simple' => qw/ language / );
 
 =head1 OVERLOADED METHODS
 
+=head2 new_result
+
+Overloaded L<DBIx::Class::ResultSet/new_result> to let creation with language and i18n columns.
+
+=cut
+
+sub new_result {
+    my $self = shift;
+
+    my @args = $self->_extract_lang(@_);
+
+    # extract i18n columns
+    my $i18n_attr = {};
+    if ( ref $args[0] eq 'HASH' ) {
+        for my $attr ( keys %{$args[0]} ) {
+            if ( $self->result_class->has_i18n_column($attr) ) {
+                $i18n_attr->{$attr} = delete $args[0]->{$attr};
+            }
+        }
+    }
+
+    my $row = $self->next::method( @args );
+
+    if ( $row && $self->language ) {
+        $row->language( $self->language );
+    }
+
+    # store i18n extracted columns
+    for my $attr ( keys %{$i18n_attr} ) {
+        $row->set_column( $attr, $i18n_attr->{$attr} );
+    }
+
+    return $row;
+}
+
 =head2 create
 
 Overloaded L<DBIx::Class::ResultSet/create> to let creation with language and i18n columns.
